#' @import bigmemory
NULL

#' @import Rcpp
NULL

#' @import jsonlite
NULL

#' @importFrom utils write.table read.delim read.table str packageVersion
NULL

#' @importFrom stats aov cor dnorm qnorm rgamma rnorm rbeta rgeom runif sd var shapiro.test na.omit lm step formula model.matrix
NULL

#' @importFrom Matrix bdiag
NULL

#' @importFrom methods getPackageName
NULL

#' @importFrom MASS mvrnorm ginv
NULL

#' @useDynLib simer
NULL
